diff --git a/src/Microsoft.AspNetCore.Session/SessionDefaults.cs b/src/Microsoft.AspNetCore.Session/SessionDefaults.cs
index 31c8748dc4..e9f590a0c7 100644
--- a/src/Microsoft.AspNetCore.Session/SessionDefaults.cs
+++ b/src/Microsoft.AspNetCore.Session/SessionDefaults.cs
@@ -9,9 +9,9 @@ namespace Microsoft.AspNetCore.Session
public static class SessionDefaults
{
///
/// Represent the default cookie name, which is ".AspNet.Session".
///
- public static readonly string CookieName = ".AspNet.Session";
+ public static readonly string CookieName = ".AspNetCore.Session";
///
/// Represents the default path used to create the cookie, which is "/".
@@ -9,9 +9,9 @@ namespace Microsoft.AspNetCore.Session
{
///
- /// Represent the default cookie name, which is ".AspNet.Session".
+ /// Represent the default cookie name, which is ".AspNetCore.Session".
///